# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/transport_socket/alts/v2alpha/alts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5envoy/config/transport_socket/alts/v2alpha/alts.proto\x12*envoy.config.transport_socket.alts.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"J\n\x04\x41lts\x12#\n\x12handshaker_service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x15peer_service_accounts\x18\x02 \x03(\tB\xd4\x01\n8io.envoyproxy.envoy.config.transport_socket.alts.v2alphaB\tAltsProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/config/transport_socket/alts/v2alpha\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.transport_sockets.alts.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.transport_socket.alts.v2alpha.alts_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.config.transport_socket.alts.v2alphaB\tAltsProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/config/transport_socket/alts/v2alpha\362\230\376\217\005,\022*envoy.extensions.transport_sockets.alts.v3\272\200\310\321\006\002\020\001'
  _ALTS.fields_by_name['handshaker_service']._options = None
  _ALTS.fields_by_name['handshaker_service']._serialized_options = b'\372B\004r\002 \001'
  _globals['_ALTS']._serialized_start=189
  _globals['_ALTS']._serialized_end=263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/geoip_providers/common/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/extensions/geoip_providers/common/v3/common.proto\x12*envoy.extensions.geoip_providers.common.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcd\x03\n\x19\x43ommonGeoipProviderConfig\x12\x83\x01\n\x12geo_headers_to_add\x18\x01 \x01(\x0b\x32].envoy.extensions.geoip_providers.common.v3.CommonGeoipProviderConfig.GeolocationHeadersToAddB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xa9\x02\n\x17GeolocationHeadersToAdd\x12\x1c\n\x07\x63ountry\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x19\n\x04\x63ity\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1b\n\x06region\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x18\n\x03\x61sn\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1c\n\x07is_anon\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_vpn\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12!\n\x0c\x61non_hosting\x18\x07 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_tor\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1f\n\nanon_proxy\x18\t \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x42\xad\x01\n8io.envoyproxy.envoy.extensions.geoip_providers.common.v3B\x0b\x43ommonProtoP\x01ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/geoip_providers/common/v3;commonv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.geoip_providers.common.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.geoip_providers.common.v3B\013CommonProtoP\001ZZgithub.com/envoyproxy/go-control-plane/envoy/extensions/geoip_providers/common/v3;commonv3\272\200\310\321\006\002\020\002'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._options = None
  _COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _COMMONGEOIPPROVIDERCONFIG.fields_by_name['geo_headers_to_add']._options = None
  _COMMONGEOIPPROVIDERCONFIG.fields_by_name['geo_headers_to_add']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_COMMONGEOIPPROVIDERCONFIG']._serialized_start=160
  _globals['_COMMONGEOIPPROVIDERCONFIG']._serialized_end=621
  _globals['_COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD']._serialized_start=324
  _globals['_COMMONGEOIPPROVIDERCONFIG_GEOLOCATIONHEADERSTOADD']._serialized_end=621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/hash_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/type/hash_policy.proto\x12\nenvoy.type\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"g\n\nHashPolicy\x12\x34\n\tsource_ip\x18\x01 \x01(\x0b\x32\x1f.envoy.type.HashPolicy.SourceIpH\x00\x1a\n\n\x08SourceIpB\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x42h\n\x18io.envoyproxy.envoy.typeB\x0fHashPolicyProtoP\x01Z1github.com/envoyproxy/go-control-plane/envoy/type\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.hash_policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030io.envoyproxy.envoy.typeB\017HashPolicyProtoP\001Z1github.com/envoyproxy/go-control-plane/envoy/type\272\200\310\321\006\002\020\001'
  _HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
  _HASHPOLICY.oneofs_by_name['policy_specifier']._serialized_options = b'\370B\001'
  _globals['_HASHPOLICY']._serialized_start=100
  _globals['_HASHPOLICY']._serialized_end=203
  _globals['_HASHPOLICY_SOURCEIP']._serialized_start=168
  _globals['_HASHPOLICY_SOURCEIP']._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/route/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2

from envoy.api.v2.route.route_components_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/route/route.proto\x12\x12\x65nvoy.api.v2.route\x1a)envoy/api/v2/route/route_components.protoBk\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/routeP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.route.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2/route'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/dubbo_proxy/v2alpha1/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.type import range_pb2 as envoy_dot_type_dot_range__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/config/filter/network/dubbo_proxy/v2alpha1/route.proto\x12\x30\x65nvoy.config.filter.network.dubbo_proxy.v2alpha1\x1a)envoy/api/v2/route/route_components.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x16\x65nvoy/type/range.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9e\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tinterface\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12G\n\x06routes\x18\x05 \x03(\x0b\x32\x37.envoy.config.filter.network.dubbo_proxy.v2alpha1.Route\"\xb6\x01\n\x05Route\x12U\n\x05match\x18\x01 \x01(\x0b\x32<.envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12V\n\x05route\x18\x02 \x01(\x0b\x32=.envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x8f\x01\n\nRouteMatch\x12M\n\x06method\x18\x01 \x01(\x0b\x32=.envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch\x12\x32\n\x07headers\x18\x02 \x03(\x0b\x32!.envoy.api.v2.route.HeaderMatcher\"|\n\x0bRouteAction\x12\x11\n\x07\x63luster\x18\x01 \x01(\tH\x00\x12@\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32#.envoy.api.v2.route.WeightedClusterH\x00\x42\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xae\x03\n\x0bMethodMatch\x12/\n\x04name\x18\x01 \x01(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x64\n\x0cparams_match\x18\x02 \x03(\x0b\x32N.envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParamsMatchEntry\x1a|\n\x17ParameterMatchSpecifier\x12\x15\n\x0b\x65xact_match\x18\x03 \x01(\tH\x00\x12-\n\x0brange_match\x18\x04 \x01(\x0b\x32\x16.envoy.type.Int64RangeH\x00\x42\x1b\n\x19parameter_match_specifier\x1a\x89\x01\n\x10ParamsMatchEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x64\n\x05value\x18\x02 \x01(\x0b\x32U.envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifier:\x02\x38\x01\x42\xe6\x01\n>io.envoyproxy.envoy.config.filter.network.dubbo_proxy.v2alpha1B\nRouteProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/dubbo_proxy/v2alpha1\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.dubbo_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.dubbo_proxy.v2alpha1.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.config.filter.network.dubbo_proxy.v2alpha1B\nRouteProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/dubbo_proxy/v2alpha1\362\230\376\217\0051\022/envoy.extensions.filters.network.dubbo_proxy.v3\272\200\310\321\006\002\020\001'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _METHODMATCH_PARAMSMATCHENTRY._options = None
  _METHODMATCH_PARAMSMATCHENTRY._serialized_options = b'8\001'
  _globals['_ROUTECONFIGURATION']._serialized_start=303
  _globals['_ROUTECONFIGURATION']._serialized_end=461
  _globals['_ROUTE']._serialized_start=464
  _globals['_ROUTE']._serialized_end=646
  _globals['_ROUTEMATCH']._serialized_start=649
  _globals['_ROUTEMATCH']._serialized_end=792
  _globals['_ROUTEACTION']._serialized_start=794
  _globals['_ROUTEACTION']._serialized_end=918
  _globals['_METHODMATCH']._serialized_start=921
  _globals['_METHODMATCH']._serialized_end=1351
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_start=1087
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_end=1211
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_start=1214
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_end=1351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/endpoint_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/api/v2/endpoint/endpoint_components.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x08\x45ndpoint\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12N\n\x13health_check_config\x18\x02 \x01(\x0b\x32\x31.envoy.api.v2.endpoint.Endpoint.HealthCheckConfig\x12\x10\n\x08hostname\x18\x03 \x01(\t\x1a\x44\n\x11HealthCheckConfig\x12\x1d\n\nport_value\x18\x01 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03\x12\x10\n\x08hostname\x18\x02 \x01(\t\"\x9a\x02\n\nLbEndpoint\x12\x33\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.EndpointH\x00\x12\x17\n\rendpoint_name\x18\x05 \x01(\tH\x00\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\x12-\n\x08metadata\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x44\n\x15load_balancing_weight\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x42\x11\n\x0fhost_identifier\"\x90\x02\n\x13LocalityLbEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x37\n\x0clb_endpoints\x18\x02 \x03(\x0b\x32!.envoy.api.v2.endpoint.LbEndpoint\x12\x44\n\x15load_balancing_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x08priority\x18\x05 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x01\x12/\n\tproximity\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xa6\x01\n#io.envoyproxy.envoy.api.v2.endpointB\x17\x45ndpointComponentsProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.endpoint.endpoint_components_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.endpointB\027EndpointComponentsProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001'
  _ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._options = None
  _ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _LBENDPOINT.fields_by_name['load_balancing_weight']._options = None
  _LBENDPOINT.fields_by_name['load_balancing_weight']._serialized_options = b'\372B\004*\002(\001'
  _LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._options = None
  _LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._serialized_options = b'\372B\004*\002(\001'
  _LOCALITYLBENDPOINTS.fields_by_name['priority']._options = None
  _LOCALITYLBENDPOINTS.fields_by_name['priority']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_ENDPOINT']._serialized_start=296
  _globals['_ENDPOINT']._serialized_end=519
  _globals['_ENDPOINT_HEALTHCHECKCONFIG']._serialized_start=451
  _globals['_ENDPOINT_HEALTHCHECKCONFIG']._serialized_end=519
  _globals['_LBENDPOINT']._serialized_start=522
  _globals['_LBENDPOINT']._serialized_end=804
  _globals['_LOCALITYLBENDPOINTS']._serialized_start=807
  _globals['_LOCALITYLBENDPOINTS']._serialized_end=1079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/random/v3/random.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.load_balancing_policies.common.v3 import common_pb2 as envoy_dot_extensions_dot_load__balancing__policies_dot_common_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/load_balancing_policies/random/v3/random.proto\x12\x32\x65nvoy.extensions.load_balancing_policies.random.v3\x1a?envoy/extensions/load_balancing_policies/common/v3/common.proto\x1a\x1dudpa/annotations/status.proto\"j\n\x06Random\x12`\n\x12locality_lb_config\x18\x01 \x01(\x0b\x32\x44.envoy.extensions.load_balancing_policies.common.v3.LocalityLbConfigB\xbd\x01\n@io.envoyproxy.envoy.extensions.load_balancing_policies.random.v3B\x0bRandomProtoP\x01Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/random/v3;randomv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.random.v3.random_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n@io.envoyproxy.envoy.extensions.load_balancing_policies.random.v3B\013RandomProtoP\001Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/random/v3;randomv3\272\200\310\321\006\002\020\002'
  _globals['_RANDOM']._serialized_start=215
  _globals['_RANDOM']._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/file_system_buffer/v3/file_system_buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.async_files.v3 import async_file_manager_pb2 as envoy_dot_extensions_dot_common_dot_async__files_dot_v3_dot_async__file__manager__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLenvoy/extensions/filters/http/file_system_buffer/v3/file_system_buffer.proto\x12\x33\x65nvoy.extensions.filters.http.file_system_buffer.v3\x1a?envoy/extensions/common/async_files/v3/async_file_manager.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x06\n\x0e\x42ufferBehavior\x12v\n\x14stream_when_possible\x18\x01 \x01(\x0b\x32V.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior.StreamWhenPossibleH\x00\x12\\\n\x06\x62ypass\x18\x02 \x01(\x0b\x32J.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior.BypassH\x00\x12\x90\x01\n\"inject_content_length_if_necessary\x18\x03 \x01(\x0b\x32\x62.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior.InjectContentLengthIfNecessaryH\x00\x12\xa4\x01\n-fully_buffer_and_always_inject_content_length\x18\x04 \x01(\x0b\x32k.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior.FullyBufferAndAlwaysInjectContentLengthH\x00\x12g\n\x0c\x66ully_buffer\x18\x05 \x01(\x0b\x32O.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior.FullyBufferH\x00\x1a\x14\n\x12StreamWhenPossible\x1a\x08\n\x06\x42ypass\x1a \n\x1eInjectContentLengthIfNecessary\x1a)\n\'FullyBufferAndAlwaysInjectContentLength\x1a\r\n\x0b\x46ullyBufferB\x0f\n\x08\x62\x65havior\x12\x03\xf8\x42\x01\"\xc2\x02\n\x0cStreamConfig\x12U\n\x08\x62\x65havior\x18\x01 \x01(\x0b\x32\x43.envoy.extensions.filters.http.file_system_buffer.v3.BufferBehavior\x12H\n\x19memory_buffer_bytes_limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02 \x00\x12@\n\x1astorage_buffer_bytes_limit\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12O\n)storage_buffer_queue_high_watermark_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\"\xda\x02\n\x1c\x46ileSystemBufferFilterConfig\x12V\n\x0emanager_config\x18\x01 \x01(\x0b\x32>.envoy.extensions.common.async_files.v3.AsyncFileManagerConfig\x12\x39\n\x13storage_buffer_path\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12R\n\x07request\x18\x03 \x01(\x0b\x32\x41.envoy.extensions.filters.http.file_system_buffer.v3.StreamConfig\x12S\n\x08response\x18\x04 \x01(\x0b\x32\x41.envoy.extensions.filters.http.file_system_buffer.v3.StreamConfigB\xdd\x01\nAio.envoyproxy.envoy.extensions.filters.http.file_system_buffer.v3B\x15\x46ileSystemBufferProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/file_system_buffer/v3;file_system_bufferv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.file_system_buffer.v3.file_system_buffer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.http.file_system_buffer.v3B\025FileSystemBufferProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/file_system_buffer/v3;file_system_bufferv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _BUFFERBEHAVIOR.oneofs_by_name['behavior']._options = None
  _BUFFERBEHAVIOR.oneofs_by_name['behavior']._serialized_options = b'\370B\001'
  _STREAMCONFIG.fields_by_name['memory_buffer_bytes_limit']._options = None
  _STREAMCONFIG.fields_by_name['memory_buffer_bytes_limit']._serialized_options = b'\372B\0042\002 \000'
  _globals['_BUFFERBEHAVIOR']._serialized_start=320
  _globals['_BUFFERBEHAVIOR']._serialized_end=1110
  _globals['_BUFFERBEHAVIOR_STREAMWHENPOSSIBLE']._serialized_start=971
  _globals['_BUFFERBEHAVIOR_STREAMWHENPOSSIBLE']._serialized_end=991
  _globals['_BUFFERBEHAVIOR_BYPASS']._serialized_start=993
  _globals['_BUFFERBEHAVIOR_BYPASS']._serialized_end=1001
  _globals['_BUFFERBEHAVIOR_INJECTCONTENTLENGTHIFNECESSARY']._serialized_start=1003
  _globals['_BUFFERBEHAVIOR_INJECTCONTENTLENGTHIFNECESSARY']._serialized_end=1035
  _globals['_BUFFERBEHAVIOR_FULLYBUFFERANDALWAYSINJECTCONTENTLENGTH']._serialized_start=1037
  _globals['_BUFFERBEHAVIOR_FULLYBUFFERANDALWAYSINJECTCONTENTLENGTH']._serialized_end=1078
  _globals['_BUFFERBEHAVIOR_FULLYBUFFER']._serialized_start=1080
  _globals['_BUFFERBEHAVIOR_FULLYBUFFER']._serialized_end=1093
  _globals['_STREAMCONFIG']._serialized_start=1113
  _globals['_STREAMCONFIG']._serialized_end=1435
  _globals['_FILESYSTEMBUFFERFILTERCONFIG']._serialized_start=1438
  _globals['_FILESYSTEMBUFFERFILTERCONFIG']._serialized_end=1784
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v3/api_listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/config/listener/v3/api_listener.proto\x12\x18\x65nvoy.config.listener.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"f\n\x0b\x41piListener\x12*\n\x0c\x61pi_listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any:+\x9a\xc5\x88\x1e&\n$envoy.config.listener.v2.ApiListenerB\x90\x01\n&io.envoyproxy.envoy.config.listener.v3B\x10\x41piListenerProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.listener.v3.api_listener_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.envoyproxy.envoy.config.listener.v3B\020ApiListenerProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\272\200\310\321\006\002\020\002'
  _APILISTENER._options = None
  _APILISTENER._serialized_options = b'\232\305\210\036&\n$envoy.config.listener.v2.ApiListener'
  _globals['_APILISTENER']._serialized_start=166
  _globals['_APILISTENER']._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15google/api/auth.proto\x12\ngoogle.api\"l\n\x0e\x41uthentication\x12-\n\x05rules\x18\x03 \x03(\x0b\x32\x1e.google.api.AuthenticationRule\x12+\n\tproviders\x18\x04 \x03(\x0b\x32\x18.google.api.AuthProvider\"\xa9\x01\n\x12\x41uthenticationRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12,\n\x05oauth\x18\x02 \x01(\x0b\x32\x1d.google.api.OAuthRequirements\x12 \n\x18\x61llow_without_credential\x18\x05 \x01(\x08\x12\x31\n\x0crequirements\x18\x07 \x03(\x0b\x32\x1b.google.api.AuthRequirement\"L\n\x0bJwtLocation\x12\x10\n\x06header\x18\x01 \x01(\tH\x00\x12\x0f\n\x05query\x18\x02 \x01(\tH\x00\x12\x14\n\x0cvalue_prefix\x18\x03 \x01(\tB\x04\n\x02in\"\x9a\x01\n\x0c\x41uthProvider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x10\n\x08jwks_uri\x18\x03 \x01(\t\x12\x11\n\taudiences\x18\x04 \x01(\t\x12\x19\n\x11\x61uthorization_url\x18\x05 \x01(\t\x12.\n\rjwt_locations\x18\x06 \x03(\x0b\x32\x17.google.api.JwtLocation\"-\n\x11OAuthRequirements\x12\x18\n\x10\x63\x61nonical_scopes\x18\x01 \x01(\t\"9\n\x0f\x41uthRequirement\x12\x13\n\x0bprovider_id\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x01(\tBk\n\x0e\x63om.google.apiB\tAuthProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\tAuthProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_AUTHENTICATION']._serialized_start=37
  _globals['_AUTHENTICATION']._serialized_end=145
  _globals['_AUTHENTICATIONRULE']._serialized_start=148
  _globals['_AUTHENTICATIONRULE']._serialized_end=317
  _globals['_JWTLOCATION']._serialized_start=319
  _globals['_JWTLOCATION']._serialized_end=395
  _globals['_AUTHPROVIDER']._serialized_start=398
  _globals['_AUTHPROVIDER']._serialized_end=552
  _globals['_OAUTHREQUIREMENTS']._serialized_start=554
  _globals['_OAUTHREQUIREMENTS']._serialized_end=599
  _globals['_AUTHREQUIREMENT']._serialized_start=601
  _globals['_AUTHREQUIREMENT']._serialized_end=658
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2


class RouteDiscoveryServiceStub(object):
    """[#protodoc-title: RDS]

    The resource_names field in DiscoveryRequest specifies a route configuration.
    This allows an Envoy configuration with multiple HTTP listeners (and
    associated HTTP connection manager filters) to use different route
    configurations. Each listener will bind its HTTP connection manager filter to
    a route table via this identifier.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamRoutes = channel.stream_stream(
                '/envoy.service.route.v3.RouteDiscoveryService/StreamRoutes',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )
        self.DeltaRoutes = channel.stream_stream(
                '/envoy.service.route.v3.RouteDiscoveryService/DeltaRoutes',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                )
        self.FetchRoutes = channel.unary_unary(
                '/envoy.service.route.v3.RouteDiscoveryService/FetchRoutes',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
                )


class RouteDiscoveryServiceServicer(object):
    """[#protodoc-title: RDS]

    The resource_names field in DiscoveryRequest specifies a route configuration.
    This allows an Envoy configuration with multiple HTTP listeners (and
    associated HTTP connection manager filters) to use different route
    configurations. Each listener will bind its HTTP connection manager filter to
    a route table via this identifier.
    """

    def StreamRoutes(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeltaRoutes(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchRoutes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RouteDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamRoutes': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamRoutes,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
            'DeltaRoutes': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaRoutes,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
            'FetchRoutes': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchRoutes,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.route.v3.RouteDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RouteDiscoveryService(object):
    """[#protodoc-title: RDS]

    The resource_names field in DiscoveryRequest specifies a route configuration.
    This allows an Envoy configuration with multiple HTTP listeners (and
    associated HTTP connection manager filters) to use different route
    configurations. Each listener will bind its HTTP connection manager filter to
    a route table via this identifier.
    """

    @staticmethod
    def StreamRoutes(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.route.v3.RouteDiscoveryService/StreamRoutes',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeltaRoutes(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.route.v3.RouteDiscoveryService/DeltaRoutes',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchRoutes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.route.v3.RouteDiscoveryService/FetchRoutes',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class VirtualHostDiscoveryServiceStub(object):
    """Virtual Host Discovery Service (VHDS) is used to dynamically update the list of virtual hosts for
    a given RouteConfiguration. If VHDS is configured a virtual host list update will be triggered
    during the processing of an HTTP request if a route for the request cannot be resolved. The
    :ref:`resource_names_subscribe <envoy_v3_api_field_service.discovery.v3.DeltaDiscoveryRequest.resource_names_subscribe>`
    field contains a list of virtual host names or aliases to track. The contents of an alias would
    be the contents of a ``host`` or ``authority`` header used to make an http request. An xDS server
    will match an alias to a virtual host based on the content of :ref:`domains'
    <envoy_v3_api_field_config.route.v3.VirtualHost.domains>` field. The ``resource_names_unsubscribe`` field
    contains a list of virtual host names that have been :ref:`unsubscribed
    <xds_protocol_unsubscribe>` from the routing table associated with the RouteConfiguration.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeltaVirtualHosts = channel.stream_stream(
                '/envoy.service.route.v3.VirtualHostDiscoveryService/DeltaVirtualHosts',
                request_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
                )


class VirtualHostDiscoveryServiceServicer(object):
    """Virtual Host Discovery Service (VHDS) is used to dynamically update the list of virtual hosts for
    a given RouteConfiguration. If VHDS is configured a virtual host list update will be triggered
    during the processing of an HTTP request if a route for the request cannot be resolved. The
    :ref:`resource_names_subscribe <envoy_v3_api_field_service.discovery.v3.DeltaDiscoveryRequest.resource_names_subscribe>`
    field contains a list of virtual host names or aliases to track. The contents of an alias would
    be the contents of a ``host`` or ``authority`` header used to make an http request. An xDS server
    will match an alias to a virtual host based on the content of :ref:`domains'
    <envoy_v3_api_field_config.route.v3.VirtualHost.domains>` field. The ``resource_names_unsubscribe`` field
    contains a list of virtual host names that have been :ref:`unsubscribed
    <xds_protocol_unsubscribe>` from the routing table associated with the RouteConfiguration.
    """

    def DeltaVirtualHosts(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VirtualHostDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeltaVirtualHosts': grpc.stream_stream_rpc_method_handler(
                    servicer.DeltaVirtualHosts,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.route.v3.VirtualHostDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VirtualHostDiscoveryService(object):
    """Virtual Host Discovery Service (VHDS) is used to dynamically update the list of virtual hosts for
    a given RouteConfiguration. If VHDS is configured a virtual host list update will be triggered
    during the processing of an HTTP request if a route for the request cannot be resolved. The
    :ref:`resource_names_subscribe <envoy_v3_api_field_service.discovery.v3.DeltaDiscoveryRequest.resource_names_subscribe>`
    field contains a list of virtual host names or aliases to track. The contents of an alias would
    be the contents of a ``host`` or ``authority`` header used to make an http request. An xDS server
    will match an alias to a virtual host based on the content of :ref:`domains'
    <envoy_v3_api_field_config.route.v3.VirtualHost.domains>` field. The ``resource_names_unsubscribe`` field
    contains a list of virtual host names that have been :ref:`unsubscribed
    <xds_protocol_unsubscribe>` from the routing table associated with the RouteConfiguration.
    """

    @staticmethod
    def DeltaVirtualHosts(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.route.v3.VirtualHostDiscoveryService/DeltaVirtualHosts',
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryRequest.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DeltaDiscoveryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/metric_value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.servicecontrol.v1 import distribution_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_distribution__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/google/api/servicecontrol/v1/metric_value.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a/google/api/servicecontrol/v1/distribution.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x03\n\x0bMetricValue\x12\x45\n\x06labels\x18\x01 \x03(\x0b\x32\x35.google.api.servicecontrol.v1.MetricValue.LabelsEntry\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x05 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x06 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x07 \x01(\tH\x00\x12H\n\x12\x64istribution_value\x18\x08 \x01(\x0b\x32*.google.api.servicecontrol.v1.DistributionH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05value\"g\n\x0eMetricValueSet\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12@\n\rmetric_values\x18\x02 \x03(\x0b\x32).google.api.servicecontrol.v1.MetricValueB\xee\x01\n com.google.api.servicecontrol.v1B\x13MetricValueSetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.metric_value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.google.api.servicecontrol.v1B\023MetricValueSetProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _METRICVALUE_LABELSENTRY._options = None
  _METRICVALUE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_METRICVALUE']._serialized_start=164
  _globals['_METRICVALUE']._serialized_end=565
  _globals['_METRICVALUE_LABELSENTRY']._serialized_start=511
  _globals['_METRICVALUE_LABELSENTRY']._serialized_end=556
  _globals['_METRICVALUESET']._serialized_start=567
  _globals['_METRICVALUESET']._serialized_end=670
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/dynamic_ot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&envoy/config/trace/v3/dynamic_ot.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x1cgoogle/protobuf/struct.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9a\x01\n\x0f\x44ynamicOtConfig\x12#\n\x07library\x18\x01 \x01(\tB\x12\x18\x01\xfa\x42\x04r\x02\x10\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x34\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0:,\x9a\xc5\x88\x1e\'\n%envoy.config.trace.v2.DynamicOtConfigB\xb8\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0e\x44ynamicOtProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.tracers.dynamic_ot.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.dynamic_ot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\016DynamicOtProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005-\022+envoy.extensions.tracers.dynamic_ot.v4alpha\272\200\310\321\006\002\020\002'
  _DYNAMICOTCONFIG.fields_by_name['library']._options = None
  _DYNAMICOTCONFIG.fields_by_name['library']._serialized_options = b'\030\001\372B\004r\002\020\001\222\307\206\330\004\0033.0'
  _DYNAMICOTCONFIG.fields_by_name['config']._options = None
  _DYNAMICOTCONFIG.fields_by_name['config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DYNAMICOTCONFIG._options = None
  _DYNAMICOTCONFIG._serialized_options = b'\232\305\210\036\'\n%envoy.config.trace.v2.DynamicOtConfig'
  _globals['_DYNAMICOTCONFIG']._serialized_start=256
  _globals['_DYNAMICOTCONFIG']._serialized_end=410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/adaptive_concurrency/v2alpha/adaptive_concurrency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPenvoy/config/filter/http/adaptive_concurrency/v2alpha/adaptive_concurrency.proto\x12\x35\x65nvoy.config.filter.http.adaptive_concurrency.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe2\x06\n\x18GradientControllerConfig\x12\x38\n\x1bsample_aggregate_percentile\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x9d\x01\n\x18\x63oncurrency_limit_params\x18\x02 \x01(\x0b\x32q.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParamsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x92\x01\n\x13min_rtt_calc_params\x18\x03 \x01(\x0b\x32k.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParamsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xb5\x01\n!ConcurrencyLimitCalculationParams\x12\x44\n\x15max_concurrency_limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12J\n\x1b\x63oncurrency_update_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x1a\x9e\x02\n\x1bMinimumRTTCalculationParams\x12\x37\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12<\n\rrequest_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12#\n\x06jitter\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12>\n\x0fmin_concurrency\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12#\n\x06\x62uffer\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\"\xf4\x01\n\x13\x41\x64\x61ptiveConcurrency\x12\x7f\n\x1agradient_controller_config\x18\x01 \x01(\x0b\x32O.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x36\n\x07\x65nabled\x18\x02 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB$\n\x1d\x63oncurrency_controller_config\x12\x03\xf8\x42\x01\x42\x84\x02\nCio.envoyproxy.envoy.config.filter.http.adaptive_concurrency.v2alphaB\x18\x41\x64\x61ptiveConcurrencyProtoP\x01Z\\github.com/envoyproxy/go-control-plane/envoy/config/filter/http/adaptive_concurrency/v2alpha\xf2\x98\xfe\x8f\x05\x37\x12\x35\x65nvoy.extensions.filters.http.adaptive_concurrency.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.adaptive_concurrency.v2alpha.adaptive_concurrency_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.config.filter.http.adaptive_concurrency.v2alphaB\030AdaptiveConcurrencyProtoP\001Z\\github.com/envoyproxy/go-control-plane/envoy/config/filter/http/adaptive_concurrency/v2alpha\362\230\376\217\0057\0225envoy.extensions.filters.http.adaptive_concurrency.v3\272\200\310\321\006\002\020\001'
  _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['max_concurrency_limit']._options = None
  _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['max_concurrency_limit']._serialized_options = b'\372B\004*\002 \000'
  _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['concurrency_update_interval']._options = None
  _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['concurrency_update_interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['interval']._options = None
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['request_count']._options = None
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['request_count']._serialized_options = b'\372B\004*\002 \000'
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['min_concurrency']._options = None
  _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['min_concurrency']._serialized_options = b'\372B\004*\002 \000'
  _GRADIENTCONTROLLERCONFIG.fields_by_name['concurrency_limit_params']._options = None
  _GRADIENTCONTROLLERCONFIG.fields_by_name['concurrency_limit_params']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GRADIENTCONTROLLERCONFIG.fields_by_name['min_rtt_calc_params']._options = None
  _GRADIENTCONTROLLERCONFIG.fields_by_name['min_rtt_calc_params']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ADAPTIVECONCURRENCY.oneofs_by_name['concurrency_controller_config']._options = None
  _ADAPTIVECONCURRENCY.oneofs_by_name['concurrency_controller_config']._serialized_options = b'\370B\001'
  _ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config']._options = None
  _ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_GRADIENTCONTROLLERCONFIG']._serialized_start=348
  _globals['_GRADIENTCONTROLLERCONFIG']._serialized_end=1214
  _globals['_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS']._serialized_start=744
  _globals['_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS']._serialized_end=925
  _globals['_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS']._serialized_start=928
  _globals['_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS']._serialized_end=1214
  _globals['_ADAPTIVECONCURRENCY']._serialized_start=1217
  _globals['_ADAPTIVECONCURRENCY']._serialized_end=1461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/path/match/uri_template/v3/uri_template_match.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/path/match/uri_template/v3/uri_template_match.proto\x12+envoy.extensions.path.match.uri_template.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\";\n\x16UriTemplateMatchConfig\x12!\n\rpath_template\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\x80\x02\x42\xbf\x01\n9io.envoyproxy.envoy.extensions.path.match.uri_template.v3B\x15UriTemplateMatchProtoP\x01Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/path/match/uri_template/v3;uri_templatev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.path.match.uri_template.v3.uri_template_match_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.extensions.path.match.uri_template.v3B\025UriTemplateMatchProtoP\001Zagithub.com/envoyproxy/go-control-plane/envoy/extensions/path/match/uri_template/v3;uri_templatev3\272\200\310\321\006\002\020\002'
  _URITEMPLATEMATCHCONFIG.fields_by_name['path_template']._options = None
  _URITEMPLATEMATCHCONFIG.fields_by_name['path_template']._serialized_options = b'\372B\007r\005\020\001\030\200\002'
  _globals['_URITEMPLATEMATCHCONFIG']._serialized_start=173
  _globals['_URITEMPLATEMATCHCONFIG']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/memory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/admin/v2alpha/memory.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1dudpa/annotations/status.proto\"\x9a\x01\n\x06Memory\x12\x11\n\tallocated\x18\x01 \x01(\x04\x12\x11\n\theap_size\x18\x02 \x01(\x04\x12\x19\n\x11pageheap_unmapped\x18\x03 \x01(\x04\x12\x15\n\rpageheap_free\x18\x04 \x01(\x04\x12\x1a\n\x12total_thread_cache\x18\x05 \x01(\x04\x12\x1c\n\x14total_physical_bytes\x18\x06 \x01(\x04\x42v\n!io.envoyproxy.envoy.admin.v2alphaB\x0bMemoryProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.memory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\013MemoryProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_MEMORY']._serialized_start=89
  _globals['_MEMORY']._serialized_end=243
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v3/circuit_breaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/config/cluster/v3/circuit_breaker.proto\x12\x17\x65nvoy.config.cluster.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xaa\x07\n\x0f\x43ircuitBreakers\x12G\n\nthresholds\x18\x01 \x03(\x0b\x32\x33.envoy.config.cluster.v3.CircuitBreakers.Thresholds\x12P\n\x13per_host_thresholds\x18\x02 \x03(\x0b\x32\x33.envoy.config.cluster.v3.CircuitBreakers.Thresholds\x1a\xce\x05\n\nThresholds\x12\x41\n\x08priority\x18\x01 \x01(\x0e\x32%.envoy.config.core.v3.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14max_pending_requests\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cmax_requests\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bmax_retries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12U\n\x0cretry_budget\x18\x08 \x01(\x0b\x32?.envoy.config.cluster.v3.CircuitBreakers.Thresholds.RetryBudget\x12\x17\n\x0ftrack_remaining\x18\x06 \x01(\x08\x12:\n\x14max_connection_pools\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1a\xbe\x01\n\x0bRetryBudget\x12.\n\x0e\x62udget_percent\x18\x01 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12;\n\x15min_retry_concurrency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:B\x9a\xc5\x88\x1e=\n;envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget:6\x9a\xc5\x88\x1e\x31\n/envoy.api.v2.cluster.CircuitBreakers.Thresholds:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.cluster.CircuitBreakersB\x90\x01\n%io.envoyproxy.envoy.config.cluster.v3B\x13\x43ircuitBreakerProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.cluster.v3.circuit_breaker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.config.cluster.v3B\023CircuitBreakerProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET._options = None
  _CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET._serialized_options = b'\232\305\210\036=\n;envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget'
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._options = None
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CIRCUITBREAKERS_THRESHOLDS._options = None
  _CIRCUITBREAKERS_THRESHOLDS._serialized_options = b'\232\305\210\0361\n/envoy.api.v2.cluster.CircuitBreakers.Thresholds'
  _CIRCUITBREAKERS._options = None
  _CIRCUITBREAKERS._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.cluster.CircuitBreakers'
  _globals['_CIRCUITBREAKERS']._serialized_start=260
  _globals['_CIRCUITBREAKERS']._serialized_end=1198
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_start=435
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_end=1153
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_start=907
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_end=1097
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/extension/v3/config_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1envoy/service/extension/v3/config_discovery.proto\x12\x1a\x65nvoy.service.extension.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\"\x0b\n\tEcdsDummy2\xfb\x03\n\x1f\x45xtensionConfigDiscoveryService\x12{\n\x16StreamExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x84\x01\n\x15\x44\x65ltaExtensionConfigs\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\xa0\x01\n\x15\x46\x65tchExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/v3/discovery:extension_configs:\x01*\x1a\x31\x8a\xa4\x96\xf3\x07+\n)envoy.config.core.v3.TypedExtensionConfigB\x99\x01\n(io.envoyproxy.envoy.service.extension.v3B\x14\x43onfigDiscoveryProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/extension/v3;extensionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.extension.v3.config_discovery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.extension.v3B\024ConfigDiscoveryProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/extension/v3;extensionv3\272\200\310\321\006\002\020\002'
  _EXTENSIONCONFIGDISCOVERYSERVICE._options = None
  _EXTENSIONCONFIGDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007+\n)envoy.config.core.v3.TypedExtensionConfig'
  _EXTENSIONCONFIGDISCOVERYSERVICE.methods_by_name['FetchExtensionConfigs']._options = None
  _EXTENSIONCONFIGDISCOVERYSERVICE.methods_by_name['FetchExtensionConfigs']._serialized_options = b'\202\323\344\223\002$\"\037/v3/discovery:extension_configs:\001*'
  _globals['_ECDSDUMMY']._serialized_start=220
  _globals['_ECDSDUMMY']._serialized_end=231
  _globals['_EXTENSIONCONFIGDISCOVERYSERVICE']._serialized_start=234
  _globals['_EXTENSIONCONFIGDISCOVERYSERVICE']._serialized_end=741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/oauth2/v3/oauth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.type.matcher.v3 import path_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_path__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/extensions/filters/http/oauth2/v3/oauth.proto\x12\'envoy.extensions.filters.http.oauth2.v3\x1a#envoy/config/core/v3/http_uri.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a envoy/type/matcher/v3/path.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x99\x04\n\x11OAuth2Credentials\x12\x1a\n\tclient_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12Z\n\x0ctoken_secret\x18\x02 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12[\n\x0bhmac_secret\x18\x03 \x01(\x0b\x32:.envoy.extensions.transport_sockets.tls.v3.SdsSecretConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\\\n\x0c\x63ookie_names\x18\x04 \x01(\x0b\x32\x46.envoy.extensions.filters.http.oauth2.v3.OAuth2Credentials.CookieNames\x1a\xb8\x01\n\x0b\x43ookieNames\x12!\n\x0c\x62\x65\x61rer_token\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1f\n\noauth_hmac\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\"\n\roauth_expires\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08id_token\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\"\n\rrefresh_token\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x42\x16\n\x0ftoken_formation\x12\x03\xf8\x42\x01\"\x80\x06\n\x0cOAuth2Config\x12\x35\n\x0etoken_endpoint\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUri\x12\'\n\x16\x61uthorization_endpoint\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12Y\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32:.envoy.extensions.filters.http.oauth2.v3.OAuth2CredentialsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1d\n\x0credirect_uri\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12K\n\x15redirect_path_matcher\x18\x05 \x01(\x0b\x32\".envoy.type.matcher.v3.PathMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x42\n\x0csignout_path\x18\x06 \x01(\x0b\x32\".envoy.type.matcher.v3.PathMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1c\n\x14\x66orward_bearer_token\x18\x07 \x01(\x08\x12\x42\n\x14pass_through_matcher\x18\x08 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x12\x13\n\x0b\x61uth_scopes\x18\t \x03(\t\x12\x11\n\tresources\x18\n \x03(\t\x12[\n\tauth_type\x18\x0b \x01(\x0e\x32>.envoy.extensions.filters.http.oauth2.v3.OAuth2Config.AuthTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x11use_refresh_token\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x12\x64\x65\x66\x61ult_expires_in\x18\r \x01(\x0b\x32\x19.google.protobuf.Duration\"0\n\x08\x41uthType\x12\x14\n\x10URL_ENCODED_BODY\x10\x00\x12\x0e\n\nBASIC_AUTH\x10\x01\"O\n\x06OAuth2\x12\x45\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x35.envoy.extensions.filters.http.oauth2.v3.OAuth2ConfigB\xa6\x01\n5io.envoyproxy.envoy.extensions.filters.http.oauth2.v3B\nOauthProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/oauth2/v3;oauth2v3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.oauth2.v3.oauth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.filters.http.oauth2.v3B\nOauthProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/oauth2/v3;oauth2v3\272\200\310\321\006\002\020\002'
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['bearer_token']._options = None
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['bearer_token']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['oauth_hmac']._options = None
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['oauth_hmac']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['oauth_expires']._options = None
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['oauth_expires']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['id_token']._options = None
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['id_token']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['refresh_token']._options = None
  _OAUTH2CREDENTIALS_COOKIENAMES.fields_by_name['refresh_token']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _OAUTH2CREDENTIALS.oneofs_by_name['token_formation']._options = None
  _OAUTH2CREDENTIALS.oneofs_by_name['token_formation']._serialized_options = b'\370B\001'
  _OAUTH2CREDENTIALS.fields_by_name['client_id']._options = None
  _OAUTH2CREDENTIALS.fields_by_name['client_id']._serialized_options = b'\372B\004r\002\020\001'
  _OAUTH2CREDENTIALS.fields_by_name['token_secret']._options = None
  _OAUTH2CREDENTIALS.fields_by_name['token_secret']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2CREDENTIALS.fields_by_name['hmac_secret']._options = None
  _OAUTH2CREDENTIALS.fields_by_name['hmac_secret']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2CONFIG.fields_by_name['authorization_endpoint']._options = None
  _OAUTH2CONFIG.fields_by_name['authorization_endpoint']._serialized_options = b'\372B\004r\002\020\001'
  _OAUTH2CONFIG.fields_by_name['credentials']._options = None
  _OAUTH2CONFIG.fields_by_name['credentials']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2CONFIG.fields_by_name['redirect_uri']._options = None
  _OAUTH2CONFIG.fields_by_name['redirect_uri']._serialized_options = b'\372B\004r\002\020\001'
  _OAUTH2CONFIG.fields_by_name['redirect_path_matcher']._options = None
  _OAUTH2CONFIG.fields_by_name['redirect_path_matcher']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2CONFIG.fields_by_name['signout_path']._options = None
  _OAUTH2CONFIG.fields_by_name['signout_path']._serialized_options = b'\372B\005\212\001\002\020\001'
  _OAUTH2CONFIG.fields_by_name['auth_type']._options = None
  _OAUTH2CONFIG.fields_by_name['auth_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_OAUTH2CREDENTIALS']._serialized_start=390
  _globals['_OAUTH2CREDENTIALS']._serialized_end=927
  _globals['_OAUTH2CREDENTIALS_COOKIENAMES']._serialized_start=719
  _globals['_OAUTH2CREDENTIALS_COOKIENAMES']._serialized_end=903
  _globals['_OAUTH2CONFIG']._serialized_start=930
  _globals['_OAUTH2CONFIG']._serialized_end=1698
  _globals['_OAUTH2CONFIG_AUTHTYPE']._serialized_start=1650
  _globals['_OAUTH2CONFIG_AUTHTYPE']._serialized_end=1698
  _globals['_OAUTH2']._serialized_start=1700
  _globals['_OAUTH2']._serialized_end=1779
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/metrics/v1/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from opencensus.proto.resource.v1 import resource_pb2 as opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)opencensus/proto/metrics/v1/metrics.proto\x12\x1bopencensus.proto.metrics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a+opencensus/proto/resource/v1/resource.proto\"\xc9\x01\n\x06Metric\x12H\n\x11metric_descriptor\x18\x01 \x01(\x0b\x32-.opencensus.proto.metrics.v1.MetricDescriptor\x12;\n\ntimeseries\x18\x02 \x03(\x0b\x32\'.opencensus.proto.metrics.v1.TimeSeries\x12\x38\n\x08resource\x18\x03 \x01(\x0b\x32&.opencensus.proto.resource.v1.Resource\"\xec\x02\n\x10MetricDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12@\n\x04type\x18\x04 \x01(\x0e\x32\x32.opencensus.proto.metrics.v1.MetricDescriptor.Type\x12\x39\n\nlabel_keys\x18\x05 \x03(\x0b\x32%.opencensus.proto.metrics.v1.LabelKey\"\xa9\x01\n\x04Type\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bGAUGE_INT64\x10\x01\x12\x10\n\x0cGAUGE_DOUBLE\x10\x02\x12\x16\n\x12GAUGE_DISTRIBUTION\x10\x03\x12\x14\n\x10\x43UMULATIVE_INT64\x10\x04\x12\x15\n\x11\x43UMULATIVE_DOUBLE\x10\x05\x12\x1b\n\x17\x43UMULATIVE_DISTRIBUTION\x10\x06\x12\x0b\n\x07SUMMARY\x10\x07\",\n\x08LabelKey\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\xb4\x01\n\nTimeSeries\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x0clabel_values\x18\x02 \x03(\x0b\x32\'.opencensus.proto.metrics.v1.LabelValue\x12\x32\n\x06points\x18\x03 \x03(\x0b\x32\".opencensus.proto.metrics.v1.Point\".\n\nLabelValue\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\thas_value\x18\x02 \x01(\x08\"\x80\x02\n\x05Point\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\x0bint64_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12L\n\x12\x64istribution_value\x18\x04 \x01(\x0b\x32..opencensus.proto.metrics.v1.DistributionValueH\x00\x12\x42\n\rsummary_value\x18\x05 \x01(\x0b\x32).opencensus.proto.metrics.v1.SummaryValueH\x00\x42\x07\n\x05value\"\xc2\x05\n\x11\x44istributionValue\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03sum\x18\x02 \x01(\x01\x12 \n\x18sum_of_squared_deviation\x18\x03 \x01(\x01\x12T\n\x0e\x62ucket_options\x18\x04 \x01(\x0b\x32<.opencensus.proto.metrics.v1.DistributionValue.BucketOptions\x12\x46\n\x07\x62uckets\x18\x05 \x03(\x0b\x32\x35.opencensus.proto.metrics.v1.DistributionValue.Bucket\x1a\x8e\x01\n\rBucketOptions\x12Y\n\x08\x65xplicit\x18\x01 \x01(\x0b\x32\x45.opencensus.proto.metrics.v1.DistributionValue.BucketOptions.ExplicitH\x00\x1a\x1a\n\x08\x45xplicit\x12\x0e\n\x06\x62ounds\x18\x01 \x03(\x01\x42\x06\n\x04type\x1a\x62\n\x06\x42ucket\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12I\n\x08\x65xemplar\x18\x02 \x01(\x0b\x32\x37.opencensus.proto.metrics.v1.DistributionValue.Exemplar\x1a\xdb\x01\n\x08\x45xemplar\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12]\n\x0b\x61ttachments\x18\x03 \x03(\x0b\x32H.opencensus.proto.metrics.v1.DistributionValue.Exemplar.AttachmentsEntry\x1a\x32\n\x10\x41ttachmentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x03\n\x0cSummaryValue\x12*\n\x05\x63ount\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03sum\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x44\n\x08snapshot\x18\x03 \x01(\x0b\x32\x32.opencensus.proto.metrics.v1.SummaryValue.Snapshot\x1a\xfa\x01\n\x08Snapshot\x12*\n\x05\x63ount\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03sum\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12_\n\x11percentile_values\x18\x03 \x03(\x0b\x32\x44.opencensus.proto.metrics.v1.SummaryValue.Snapshot.ValueAtPercentile\x1a\x36\n\x11ValueAtPercentile\x12\x12\n\npercentile\x18\x01 \x01(\x01\x12\r\n\x05value\x18\x02 \x01(\x01\x42\x94\x01\n\x1eio.opencensus.proto.metrics.v1B\x0cMetricsProtoP\x01ZDgithub.com/census-instrumentation/opencensus-proto/gen-go/metrics/v1\xea\x02\x1bOpenCensus.Proto.Metrics.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opencensus.proto.metrics.v1.metrics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.opencensus.proto.metrics.v1B\014MetricsProtoP\001ZDgithub.com/census-instrumentation/opencensus-proto/gen-go/metrics/v1\352\002\033OpenCensus.Proto.Metrics.V1'
  _DISTRIBUTIONVALUE_EXEMPLAR_ATTACHMENTSENTRY._options = None
  _DISTRIBUTIONVALUE_EXEMPLAR_ATTACHMENTSENTRY._serialized_options = b'8\001'
  _globals['_METRIC']._serialized_start=185
  _globals['_METRIC']._serialized_end=386
  _globals['_METRICDESCRIPTOR']._serialized_start=389
  _globals['_METRICDESCRIPTOR']._serialized_end=753
  _globals['_METRICDESCRIPTOR_TYPE']._serialized_start=584
  _globals['_METRICDESCRIPTOR_TYPE']._serialized_end=753
  _globals['_LABELKEY']._serialized_start=755
  _globals['_LABELKEY']._serialized_end=799
  _globals['_TIMESERIES']._serialized_start=802
  _globals['_TIMESERIES']._serialized_end=982
  _globals['_LABELVALUE']._serialized_start=984
  _globals['_LABELVALUE']._serialized_end=1030
  _globals['_POINT']._serialized_start=1033
  _globals['_POINT']._serialized_end=1289
  _globals['_DISTRIBUTIONVALUE']._serialized_start=1292
  _globals['_DISTRIBUTIONVALUE']._serialized_end=1998
  _globals['_DISTRIBUTIONVALUE_BUCKETOPTIONS']._serialized_start=1534
  _globals['_DISTRIBUTIONVALUE_BUCKETOPTIONS']._serialized_end=1676
  _globals['_DISTRIBUTIONVALUE_BUCKETOPTIONS_EXPLICIT']._serialized_start=1642
  _globals['_DISTRIBUTIONVALUE_BUCKETOPTIONS_EXPLICIT']._serialized_end=1668
  _globals['_DISTRIBUTIONVALUE_BUCKET']._serialized_start=1678
  _globals['_DISTRIBUTIONVALUE_BUCKET']._serialized_end=1776
  _globals['_DISTRIBUTIONVALUE_EXEMPLAR']._serialized_start=1779
  _globals['_DISTRIBUTIONVALUE_EXEMPLAR']._serialized_end=1998
  _globals['_DISTRIBUTIONVALUE_EXEMPLAR_ATTACHMENTSENTRY']._serialized_start=1948
  _globals['_DISTRIBUTIONVALUE_EXEMPLAR_ATTACHMENTSENTRY']._serialized_end=1998
  _globals['_SUMMARYVALUE']._serialized_start=2001
  _globals['_SUMMARYVALUE']._serialized_end=2425
  _globals['_SUMMARYVALUE_SNAPSHOT']._serialized_start=2175
  _globals['_SUMMARYVALUE_SNAPSHOT']._serialized_end=2425
  _globals['_SUMMARYVALUE_SNAPSHOT_VALUEATPERCENTILE']._serialized_start=2371
  _globals['_SUMMARYVALUE_SNAPSHOT_VALUEATPERCENTILE']._serialized_end=2425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/router/v2/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/filter/http/router/v2/router.proto\x12\"envoy.config.filter.http.router.v2\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x93\x03\n\x06Router\x12\x31\n\rdynamic_stats\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10start_child_span\x18\x02 \x01(\x08\x12\x41\n\x0cupstream_log\x18\x03 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x12\x1e\n\x16suppress_envoy_headers\x18\x04 \x01(\x08\x12\xb3\x01\n\x14strict_check_headers\x18\x05 \x03(\tB\x94\x01\xfa\x42\x90\x01\x92\x01\x8c\x01\"\x89\x01r\x86\x01R\x1ex-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\x13x-envoy-max-retriesR\x15x-envoy-retry-grpc-onR\x10x-envoy-retry-on\x12#\n\x1brespect_expected_rq_timeout\x18\x06 \x01(\x08\x42\xcc\x01\n0io.envoyproxy.envoy.config.filter.http.router.v2B\x0bRouterProtoP\x01ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/router/v2;routerv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.filters.http.router.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.router.v2.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n0io.envoyproxy.envoy.config.filter.http.router.v2B\013RouterProtoP\001ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/router/v2;routerv2\362\230\376\217\005)\022\'envoy.extensions.filters.http.router.v3\272\200\310\321\006\002\020\001'
  _ROUTER.fields_by_name['strict_check_headers']._options = None
  _ROUTER.fields_by_name['strict_check_headers']._serialized_options = b'\372B\220\001\222\001\214\001\"\211\001r\206\001R\036x-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\023x-envoy-max-retriesR\025x-envoy-retry-grpc-onR\020x-envoy-retry-on'
  _globals['_ROUTER']._serialized_start=258
  _globals['_ROUTER']._serialized_end=661
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/header_validators/envoy_default/v3/header_validator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOenvoy/extensions/http/header_validators/envoy_default/v3/header_validator.proto\x12\x38\x65nvoy.extensions.http.header_validators.envoy_default.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd5\x08\n\x15HeaderValidatorConfig\x12\x84\x01\n\x16http1_protocol_options\x18\x01 \x01(\x0b\x32\x64.envoy.extensions.http.header_validators.envoy_default.v3.HeaderValidatorConfig.Http1ProtocolOptions\x12\x93\x01\n\x1euri_path_normalization_options\x18\x02 \x01(\x0b\x32k.envoy.extensions.http.header_validators.envoy_default.v3.HeaderValidatorConfig.UriPathNormalizationOptions\x12\x1d\n\x15restrict_http_methods\x18\x03 \x01(\x08\x12\x95\x01\n\x1fheaders_with_underscores_action\x18\x04 \x01(\x0e\x32l.envoy.extensions.http.header_validators.envoy_default.v3.HeaderValidatorConfig.HeadersWithUnderscoresAction\x12 \n\x18strip_fragment_from_path\x18\x05 \x01(\x08\x1a\xbf\x03\n\x1bUriPathNormalizationOptions\x12\x1f\n\x17skip_path_normalization\x18\x01 \x01(\x08\x12\x1c\n\x14skip_merging_slashes\x18\x02 \x01(\x08\x12\xbd\x01\n path_with_escaped_slashes_action\x18\x03 \x01(\x0e\x32\x88\x01.envoy.extensions.http.header_validators.envoy_default.v3.HeaderValidatorConfig.UriPathNormalizationOptions.PathWithEscapedSlashesActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\xa0\x01\n\x1cPathWithEscapedSlashesAction\x12#\n\x1fIMPLEMENTATION_SPECIFIC_DEFAULT\x10\x00\x12\x12\n\x0eKEEP_UNCHANGED\x10\x01\x12\x12\n\x0eREJECT_REQUEST\x10\x02\x12\x19\n\x15UNESCAPE_AND_REDIRECT\x10\x03\x12\x18\n\x14UNESCAPE_AND_FORWARD\x10\x04\x1a\x34\n\x14Http1ProtocolOptions\x12\x1c\n\x14\x61llow_chunked_length\x18\x01 \x01(\x08\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02\x42\xd9\x01\nFio.envoyproxy.envoy.extensions.http.header_validators.envoy_default.v3B\x14HeaderValidatorProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/http/header_validators/envoy_default/v3;envoy_defaultv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.header_validators.envoy_default.v3.header_validator_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nFio.envoyproxy.envoy.extensions.http.header_validators.envoy_default.v3B\024HeaderValidatorProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/http/header_validators/envoy_default/v3;envoy_defaultv3\272\200\310\321\006\002\020\002'
  _HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS.fields_by_name['path_with_escaped_slashes_action']._options = None
  _HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS.fields_by_name['path_with_escaped_slashes_action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_HEADERVALIDATORCONFIG']._serialized_start=198
  _globals['_HEADERVALIDATORCONFIG']._serialized_end=1307
  _globals['_HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS']._serialized_start=726
  _globals['_HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS']._serialized_end=1173
  _globals['_HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS_PATHWITHESCAPEDSLASHESACTION']._serialized_start=1013
  _globals['_HEADERVALIDATORCONFIG_URIPATHNORMALIZATIONOPTIONS_PATHWITHESCAPEDSLASHESACTION']._serialized_end=1173
  _globals['_HEADERVALIDATORCONFIG_HTTP1PROTOCOLOPTIONS']._serialized_start=1175
  _globals['_HEADERVALIDATORCONFIG_HTTP1PROTOCOLOPTIONS']._serialized_end=1227
  _globals['_HEADERVALIDATORCONFIG_HEADERSWITHUNDERSCORESACTION']._serialized_start=1229
  _globals['_HEADERVALIDATORCONFIG_HEADERSWITHUNDERSCORESACTION']._serialized_end=1307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/endpoint/v3/eds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/service/endpoint/v3/eds.proto\x12\x19\x65nvoy.service.endpoint.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08\x45\x64sDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.EdsDummy2\xdb\x03\n\x18\x45ndpointDiscoveryService\x12t\n\x0fStreamEndpoints\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12}\n\x0e\x44\x65ltaEndpoints\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x91\x01\n\x0e\x46\x65tchEndpoints\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v3/discovery:endpoints:\x01*\x1a\x36\x8a\xa4\x96\xf3\x07\x30\n.envoy.config.endpoint.v3.ClusterLoadAssignmentB\x8a\x01\n\'io.envoyproxy.envoy.service.endpoint.v3B\x08\x45\x64sProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/service/endpoint/v3;endpointv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.endpoint.v3.eds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.service.endpoint.v3B\010EdsProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/service/endpoint/v3;endpointv3\272\200\310\321\006\002\020\002'
  _EDSDUMMY._options = None
  _EDSDUMMY._serialized_options = b'\232\305\210\036\027\n\025envoy.api.v2.EdsDummy'
  _ENDPOINTDISCOVERYSERVICE._options = None
  _ENDPOINTDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\0070\n.envoy.config.endpoint.v3.ClusterLoadAssignment'
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._options = None
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._serialized_options = b'\202\323\344\223\002\034\"\027/v3/discovery:endpoints:\001*'
  _globals['_EDSDUMMY']._serialized_start=240
  _globals['_EDSDUMMY']._serialized_end=280
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_start=283
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_end=758
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/api/v2/core/protocol.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x14\n\x12TcpProtocolOptions\"L\n\x1bUpstreamHttpProtocolOptions\x12\x10\n\x08\x61uto_sni\x18\x01 \x01(\x08\x12\x1b\n\x13\x61uto_san_validation\x18\x02 \x01(\x08\"\xba\x03\n\x13HttpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17max_connection_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x11max_headers_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x13max_stream_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12l\n\x1fheaders_with_underscores_action\x18\x05 \x01(\x0e\x32\x43.envoy.api.v2.core.HttpProtocolOptions.HeadersWithUnderscoresAction\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02\"\x98\x03\n\x14Http1ProtocolOptions\x12\x36\n\x12\x61llow_absolute_url\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x63\x63\x65pt_http_10\x18\x02 \x01(\x08\x12 \n\x18\x64\x65\x66\x61ult_host_for_http_10\x18\x03 \x01(\t\x12R\n\x11header_key_format\x18\x04 \x01(\x0b\x32\x37.envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat\x12\x17\n\x0f\x65nable_trailers\x18\x05 \x01(\x08\x1a\xa0\x01\n\x0fHeaderKeyFormat\x12\x64\n\x11proper_case_words\x18\x01 \x01(\x0b\x32G.envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWordsH\x00\x1a\x11\n\x0fProperCaseWordsB\x14\n\rheader_format\x12\x03\xf8\x42\x01\"\xb0\x08\n\x14Http2ProtocolOptions\x12\x36\n\x10hpack_table_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12K\n\x16max_concurrent_streams\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\r\xfa\x42\n*\x08\x18\xff\xff\xff\xff\x07(\x01\x12Q\n\x1ainitial_stream_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12U\n\x1einitial_connection_window_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12\x15\n\rallow_connect\x18\x05 \x01(\x08\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\x12\x42\n\x13max_outbound_frames\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12J\n\x1bmax_outbound_control_frames\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12W\n1max_consecutive_inbound_frames_with_empty_payload\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12L\n&max_inbound_priority_frames_per_stream\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x63\n4max_inbound_window_update_frames_per_data_frame_sent\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12.\n&stream_error_on_invalid_http_messaging\x18\x0c \x01(\x08\x12]\n\x1a\x63ustom_settings_parameters\x18\r \x03(\x0b\x32\x39.envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter\x1a\x8e\x01\n\x11SettingsParameter\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x10\xfa\x42\r*\x06\x18\x80\x80\x04(\x01\x8a\x01\x02\x10\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"^\n\x13GrpcProtocolOptions\x12G\n\x16http2_protocol_options\x18\x01 \x01(\x0b\x32\'.envoy.api.v2.core.Http2ProtocolOptionsB\x90\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\rProtocolProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\rProtocolProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._options = None
  _HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._serialized_options = b'\372B\004*\002(\001'
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._options = None
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._serialized_options = b'\370B\001'
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._options = None
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._serialized_options = b'\372B\r*\006\030\200\200\004(\001\212\001\002\020\001'
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._options = None
  _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._serialized_options = b'\372B\n*\010\030\377\377\377\377\007(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._serialized_options = b'\372B\004*\002(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._serialized_options = b'\372B\004*\002(\001'
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._options = None
  _HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._serialized_options = b'\372B\004*\002(\001'
  _globals['_TCPPROTOCOLOPTIONS']._serialized_start=207
  _globals['_TCPPROTOCOLOPTIONS']._serialized_end=227
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_start=229
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_end=305
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_start=308
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_end=750
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_start=672
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_end=750
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_start=753
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_end=1161
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_start=1001
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_end=1161
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_start=1122
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_end=1139
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_start=1164
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_end=2236
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_start=2094
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_end=2236
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_start=2238
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_end=2332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/resource_monitors/injected_resource/v3/injected_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOenvoy/extensions/resource_monitors/injected_resource/v3/injected_resource.proto\x12\x37\x65nvoy.extensions.resource_monitors.injected_resource.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8a\x01\n\x16InjectedResourceConfig\x12\x19\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:U\x9a\xc5\x88\x1eP\nNenvoy.config.resource_monitor.injected_resource.v2alpha.InjectedResourceConfigB\xdc\x01\nEio.envoyproxy.envoy.extensions.resource_monitors.injected_resource.v3B\x15InjectedResourceProtoP\x01Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/injected_resource/v3;injected_resourcev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.resource_monitors.injected_resource.v3.injected_resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEio.envoyproxy.envoy.extensions.resource_monitors.injected_resource.v3B\025InjectedResourceProtoP\001Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/injected_resource/v3;injected_resourcev3\272\200\310\321\006\002\020\002'
  _INJECTEDRESOURCECONFIG.fields_by_name['filename']._options = None
  _INJECTEDRESOURCECONFIG.fields_by_name['filename']._serialized_options = b'\372B\004r\002\020\001'
  _INJECTEDRESOURCECONFIG._options = None
  _INJECTEDRESOURCECONFIG._serialized_options = b'\232\305\210\036P\nNenvoy.config.resource_monitor.injected_resource.v2alpha.InjectedResourceConfig'
  _globals['_INJECTEDRESOURCECONFIG']._serialized_start=232
  _globals['_INJECTEDRESOURCECONFIG']._serialized_end=370
# @@protoc_insertion_point(module_scope)
